@@ -9,34 +9,33 @@ from requests.auth import AuthBase
 from .compat import urlparse, json, b
 from .utils import urlsafe_base64_encode
 
-
 # 上传策略，参数规格详见
 # https://developer.qiniu.com/kodo/manual/1206/put-policy
 _policy_fields = set([
-    'callbackUrl',       # 回调URL
-    'callbackBody',      # 回调Body
-    'callbackHost',      # 回调URL指定的Host
+    'callbackUrl',  # 回调URL
+    'callbackBody',  # 回调Body
+    'callbackHost',  # 回调URL指定的Host
     'callbackBodyType',  # 回调Body的Content-Type
     'callbackFetchKey',  # 回调FetchKey模式开关
 
-    'returnUrl',         # 上传端的303跳转URL
-    'returnBody',        # 上传端简单反馈获取的Body
+    'returnUrl',  # 上传端的303跳转URL
+    'returnBody',  # 上传端简单反馈获取的Body
 
-    'endUser',           # 回调时上传端标识
-    'saveKey',           # 自定义资源名
-    'insertOnly',        # 插入模式开关
+    'endUser',  # 回调时上传端标识
+    'saveKey',  # 自定义资源名
+    'insertOnly',  # 插入模式开关
 
-    'detectMime',        # MimeType侦测开关
-    'mimeLimit',         # MimeType限制
-    'fsizeLimit',        # 上传文件大小限制
-    'fsizeMin',          # 上传文件最少字节数
+    'detectMime',  # MimeType侦测开关
+    'mimeLimit',  # MimeType限制
+    'fsizeLimit',  # 上传文件大小限制
+    'fsizeMin',  # 上传文件最少字节数
 
-    'persistentOps',        # 持久化处理操作
+    'persistentOps',  # 持久化处理操作
     'persistentNotifyUrl',  # 持久化处理结果通知URL
-    'persistentPipeline',   # 持久化处理独享队列
-    'deleteAfterDays',      # 文件多少天后自动删除
-    'fileType',             # 文件的存储类型，0为普通存储，1为低频存储
-    'isPrefixalScope'       # 指定上传文件必须使用的前缀
+    'persistentPipeline',  # 持久化处理独享队列
+    'deleteAfterDays',  # 文件多少天后自动删除
+    'fileType',  # 文件的存储类型，0为普通存储，1为低频存储
+    'isPrefixalScope'  # 指定上传文件必须使用的前缀
 ])
 
 
@@ -69,7 +68,8 @@ class Auth(object):
 
     def token_with_data(self, data):
         data = urlsafe_base64_encode(data)
-        return '{0}:{1}:{2}'.format(self.__access_key, self.__token(data), data)
+        return '{0}:{1}:{2}'.format(
+            self.__access_key, self.__token(data), data)
 
     def token_of_request(self, url, body=None, content_type=None):
         """带请求体的签名（本质上是管理凭证的签名）
@@ -124,7 +124,13 @@ class Auth(object):
         token = self.token(url)
         return '{0}&token={1}'.format(url, token)
 
-    def upload_token(self, bucket, key=None, expires=3600, policy=None, strict_policy=True):
+    def upload_token(
+            self,
+            bucket,
+            key=None,
+            expires=3600,
+            policy=None,
+            strict_policy=True):
         """生成上传凭证
 
         Args:
@@ -157,7 +163,12 @@ class Auth(object):
         data = json.dumps(policy, separators=(',', ':'))
         return self.token_with_data(data)
 
-    def verify_callback(self, origin_authorization, url, body, content_type='application/x-www-form-urlencoded'):
+    def verify_callback(
+            self,
+            origin_authorization,
+            url,
+            body,
+            content_type='application/x-www-form-urlencoded'):
         """回调验证
 
         Args:
@@ -186,7 +197,8 @@ class RequestsAuth(AuthBase):
 
     def __call__(self, r):
         if r.body is not None and r.headers['Content-Type'] == 'application/x-www-form-urlencoded':
-            token = self.auth.token_of_request(r.url, r.body, 'application/x-www-form-urlencoded')
+            token = self.auth.token_of_request(
+                r.url, r.body, 'application/x-www-form-urlencoded')
         else:
             token = self.auth.token_of_request(r.url)
         r.headers['Authorization'] = 'QBox {0}'.format(token)
@@ -215,7 +227,14 @@ class QiniuMacAuth(object):
         hashed = hmac.new(self.__secret_key, data, sha1)
         return urlsafe_base64_encode(hashed.digest())
 
-    def token_of_request(self, method, host, url, qheaders, content_type=None, body=None):
+    def token_of_request(
+            self,
+            method,
+            host,
+            url,
+            qheaders,
+            content_type=None,
+            body=None):
         """
         <Method> <PathWithRawQuery>
         Host: <Host>
@@ -236,7 +255,9 @@ class QiniuMacAuth(object):
         path_with_query = path
         if query != '':
             path_with_query = ''.join([path_with_query, '?', query])
-        data = ''.join(["%s %s" % (method, path_with_query), "\n", "Host: %s" % host, "\n"])
+        data = ''.join(["%s %s" %
+                        (method, path_with_query), "\n", "Host: %s" %
+                        host, "\n"])
 
         if content_type:
             data += "Content-Type: %s" % (content_type) + "\n"
@@ -253,7 +274,7 @@ class QiniuMacAuth(object):
         res = ""
         for key in headers:
             if key.startswith(self.qiniu_header_prefix):
-                res += key+": %s\n" % (headers.get(key))
+                res += key + ": %s\n" % (headers.get(key))
         return res
 
     @staticmethod
@@ -272,6 +293,6 @@ class QiniuMacRequestsAuth(AuthBase):
             r.url, self.auth.qiniu_headers(r.headers),
             r.headers.get('Content-Type', None),
             r.body
-            )
+        )
         r.headers['Authorization'] = 'Qiniu {0}'.format(token)
         return r
