@@ -4,6 +4,7 @@ import platform
 import requests
 from requests.auth import AuthBase
 
+from qiniu.compat import is_py2, is_py3
 from qiniu import config
 import qiniu.auth
 from . import __version__
@@ -11,7 +12,8 @@ from . import __version__
 _sys_info = '{0}; {1}'.format(platform.system(), platform.machine())
 _python_ver = platform.python_version()
 
-USER_AGENT = 'QiniuPython/{0} ({1}; ) Python/{2}'.format(__version__, _sys_info, _python_ver)
+USER_AGENT = 'QiniuPython/{0} ({1}; ) Python/{2}'.format(
+    __version__, _sys_info, _python_ver)
 
 _session = None
 _headers = {'User-Agent': USER_AGENT}
@@ -20,14 +22,18 @@ _headers = {'User-Agent': USER_AGENT}
 def __return_wrapper(resp):
     if resp.status_code != 200 or resp.headers.get('X-Reqid') is None:
         return None, ResponseInfo(resp)
-    ret = resp.json() if resp.text != '' else {}
+    resp.encoding = 'utf-8'
+    ret = resp.json(encoding='utf-8') if resp.text != '' else {}
+    if ret is None: # json null
+        ret = {}
     return ret, ResponseInfo(resp)
 
 
 def _init():
     session = requests.Session()
     adapter = requests.adapters.HTTPAdapter(
-        pool_connections=config.get_default('connection_pool'), pool_maxsize=config.get_default('connection_pool'),
+        pool_connections=config.get_default('connection_pool'),
+        pool_maxsize=config.get_default('connection_pool'),
         max_retries=config.get_default('connection_retries'))
     session.mount('http://', adapter)
     global _session
@@ -38,7 +44,7 @@ def _post(url, data, files, auth, headers=None):
     if _session is None:
         _init()
     try:
-        post_headers = _headers
+        post_headers = _headers.copy()
         if headers is not None:
             for k, v in headers.items():
                 post_headers.update({k: v})
@@ -50,11 +56,30 @@ def _post(url, data, files, auth, headers=None):
     return __return_wrapper(r)
 
 
+def _put(url, data, files, auth, headers=None):
+    if _session is None:
+        _init()
+    try:
+        post_headers = _headers.copy()
+        if headers is not None:
+            for k, v in headers.items():
+                post_headers.update({k: v})
+        r = _session.put(
+            url, data=data, files=files, auth=auth, headers=post_headers,
+            timeout=config.get_default('connection_timeout'))
+    except Exception as e:
+        return None, ResponseInfo(None, e)
+    return __return_wrapper(r)
+
+
 def _get(url, params, auth):
     try:
         r = requests.get(
-            url, params=params, auth=qiniu.auth.RequestsAuth(auth) if auth is not None else None,
-            timeout=config.get_default('connection_timeout'), headers=_headers)
+            url,
+            params=params,
+            auth=qiniu.auth.RequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'),
+            headers=_headers)
     except Exception as e:
         return None, ResponseInfo(None, e)
     return __return_wrapper(r)
@@ -85,12 +110,26 @@ def _post_with_auth_and_headers(url, data, auth, headers):
     return _post(url, data, None, qiniu.auth.RequestsAuth(auth), headers)
 
 
+def _put_with_auth(url, data, auth):
+    return _put(url, data, None, qiniu.auth.RequestsAuth(auth))
+
+
+def _put_with_auth_and_headers(url, data, auth, headers):
+    return _put(url, data, None, qiniu.auth.RequestsAuth(auth), headers)
+
+
 def _post_with_qiniu_mac(url, data, auth):
-    qn_auth = qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None
+    qn_auth = qiniu.auth.QiniuMacRequestsAuth(
+        auth) if auth is not None else None
     timeout = config.get_default('connection_timeout')
 
     try:
-        r = requests.post(url, json=data, auth=qn_auth, timeout=timeout, headers=_headers)
+        r = requests.post(
+            url,
+            json=data,
+            auth=qn_auth,
+            timeout=timeout,
+            headers=_headers)
     except Exception as e:
         return None, ResponseInfo(None, e)
     return __return_wrapper(r)
@@ -99,8 +138,11 @@ def _post_with_qiniu_mac(url, data, auth):
 def _get_with_qiniu_mac(url, params, auth):
     try:
         r = requests.get(
-            url, params=params, auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
-            timeout=config.get_default('connection_timeout'), headers=_headers)
+            url,
+            params=params,
+            auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'),
+            headers=_headers)
     except Exception as e:
         return None, ResponseInfo(None, e)
     return __return_wrapper(r)
@@ -109,8 +151,11 @@ def _get_with_qiniu_mac(url, params, auth):
 def _delete_with_qiniu_mac(url, params, auth):
     try:
         r = requests.delete(
-            url, params=params, auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
-            timeout=config.get_default('connection_timeout'), headers=_headers)
+            url,
+            params=params,
+            auth=qiniu.auth.QiniuMacRequestsAuth(auth) if auth is not None else None,
+            timeout=config.get_default('connection_timeout'),
+            headers=_headers)
     except Exception as e:
         return None, ResponseInfo(None, e)
     return __return_wrapper(r)
@@ -168,7 +213,12 @@ class ResponseInfo(object):
         return self.__response is None or self.req_id is None
 
     def __str__(self):
-        return ', '.join(['%s:%s' % item for item in self.__dict__.items()])
+        if is_py2:
+            return ', '.join(
+                ['%s:%s' % item for item in self.__dict__.items()]).encode('utf-8')
+        elif is_py3:
+            return ', '.join(['%s:%s' %
+                              item for item in self.__dict__.items()])
 
     def __repr__(self):
         return self.__str__()
